package com.fizz.business.service.impl;

import java.util.Arrays;
import java.util.List;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fizz.business.mapper.PdiSetupMapper;
import com.fizz.business.domain.PdiSetups;
import com.fizz.business.service.IPdiSetupService;

/**
 * 生产计划的参数详情Service业务层处理
 * 
 * @author Joshi
 * @date 2025-09-25
 */
@Service
public class PdiSetupServiceImpl extends ServiceImpl<PdiSetupMapper, PdiSetups> implements IPdiSetupService {
    /**
     * 查询生产计划的参数详情
     * 
     * @param id 生产计划的参数详情主键
     * @return 生产计划的参数详情
     */
    @Override
    public PdiSetups selectPdiSetupByid(Long id)
    {
        return baseMapper.selectById(id);
    }

    /**
     * 查询生产计划的参数详情列表
     * 
     * @param pdiSetup 生产计划的参数详情
     * @return 生产计划的参数详情
     */
    @Override
    public List<PdiSetups> selectPdiSetupList(PdiSetups pdiSetup)
    {
        QueryWrapper<PdiSetups> queryWrapper = new QueryWrapper<>(pdiSetup);
        queryWrapper.orderByDesc("create_time");
        return baseMapper.selectList(queryWrapper);
    }

    /**
     * 新增生产计划的参数详情
     * 
     * @param pdiSetup 生产计划的参数详情
     * @return 结果
     */
    @Override
    public Boolean insertPdiSetup(PdiSetups pdiSetup)
    {
        return this.save(pdiSetup);
    }

    /**
     * 修改生产计划的参数详情
     * 
     * @param pdiSetup 生产计划的参数详情
     * @return 结果
     */
    @Override
    public Boolean updatePdiSetup(PdiSetups pdiSetup)
    {
        return this.updateById(pdiSetup);
    }

    /**
     * 批量删除生产计划的参数详情
     * 
     * @param ids 需要删除的生产计划的参数详情主键
     * @return 结果
     */
    @Override
    public Boolean deletePdiSetupByids(Long[] ids)
    {
        return this.removeByIds(Arrays.asList(ids));
    }

    /**
     * 删除生产计划的参数详情信息
     * 
     * @param id 生产计划的参数详情主键
     * @return 结果
     */
    @Override
    public Boolean deletePdiSetupByid(Long id)
    {
        return this.removeById(id);
    }
}
